# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.servicedirectory.v1",
    manifest={
        "Endpoint",
    },
)


class Endpoint(proto.Message):
    r"""An individual endpoint that provides a
    [service][google.cloud.servicedirectory.v1.Service]. The service
    must already exist to create an endpoint.

    Attributes:
        name (str):
            Immutable. The resource name for the endpoint in the format
            ``projects/*/locations/*/namespaces/*/services/*/endpoints/*``.
        address (str):
            Optional. An IPv4 or IPv6 address. Service Directory will
            reject bad addresses like: "8.8.8" "8.8.8.8:53"
            "test:bad:address" "[::1]" "[::1]:8080" Limited to 45
            characters.
        port (int):
            Optional. Service Directory will reject values outside of
            [0, 65535].
        annotations (MutableMapping[str, str]):
            Optional. Annotations for the endpoint. This data can be
            consumed by service clients. Restrictions:

            -  The entire annotations dictionary may contain up to 512
               characters, spread accoss all key-value pairs.
               Annotations that goes beyond any these limits will be
               rejected.
            -  Valid annotation keys have two segments: an optional
               prefix and name, separated by a slash (/). The name
               segment is required and must be 63 characters or less,
               beginning and ending with an alphanumeric character
               ([a-z0-9A-Z]) with dashes (-), underscores (_), dots (.),
               and alphanumerics between. The prefix is optional. If
               specified, the prefix must be a DNS subdomain: a series
               of DNS labels separated by dots (.), not longer than 253
               characters in total, followed by a slash (/). Annotations
               that fails to meet these requirements will be rejected.
            -  The '(*.)google.com/' and '(*.)googleapis.com/' prefixes
               are reserved for system annotations managed by Service
               Directory. If the user tries to write to these keyspaces,
               those entries will be silently ignored by the system.
               Note: This field is equivalent to the 'metadata' field in
               the v1beta1 API. They have the same syntax and read/write
               to the same location in Service Directory.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    address: str = proto.Field(
        proto.STRING,
        number=2,
    )
    port: int = proto.Field(
        proto.INT32,
        number=3,
    )
    annotations: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=5,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.servicedirectory_v1.types import endpoint as gcs_endpoint
from google.cloud.servicedirectory_v1.types import namespace as gcs_namespace
from google.cloud.servicedirectory_v1.types import service as gcs_service

__protobuf__ = proto.module(
    package="google.cloud.servicedirectory.v1",
    manifest={
        "CreateNamespaceRequest",
        "ListNamespacesRequest",
        "ListNamespacesResponse",
        "GetNamespaceRequest",
        "UpdateNamespaceRequest",
        "DeleteNamespaceRequest",
        "CreateServiceRequest",
        "ListServicesRequest",
        "ListServicesResponse",
        "GetServiceRequest",
        "UpdateServiceRequest",
        "DeleteServiceRequest",
        "CreateEndpointRequest",
        "ListEndpointsRequest",
        "ListEndpointsResponse",
        "GetEndpointRequest",
        "UpdateEndpointRequest",
        "DeleteEndpointRequest",
    },
)


class CreateNamespaceRequest(proto.Message):
    r"""The request message for
    [RegistrationService.CreateNamespace][google.cloud.servicedirectory.v1.RegistrationService.CreateNamespace].

    Attributes:
        parent (str):
            Required. The resource name of the project
            and location the namespace will be created in.
        namespace_id (str):
            Required. The Resource ID must be 1-63 characters long, and
            comply with RFC1035. Specifically, the name must be 1-63
            characters long and match the regular expression
            ``[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?`` which means the first
            character must be a lowercase letter, and all following
            characters must be a dash, lowercase letter, or digit,
            except the last character, which cannot be a dash.
        namespace (google.cloud.servicedirectory_v1.types.Namespace):
            Required. A namespace with initial fields
            set.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    namespace_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    namespace: gcs_namespace.Namespace = proto.Field(
        proto.MESSAGE,
        number=3,
        message=gcs_namespace.Namespace,
    )


class ListNamespacesRequest(proto.Message):
    r"""The request message for
    [RegistrationService.ListNamespaces][google.cloud.servicedirectory.v1.RegistrationService.ListNamespaces].

    Attributes:
        parent (str):
            Required. The resource name of the project
            and location whose namespaces we'd like to list.
        page_size (int):
            Optional. The maximum number of items to
            return.
        page_token (str):
            Optional. The next_page_token value returned from a previous
            List request, if any.
        filter (str):
            Optional. The filter to list result by.

            General filter string syntax: () can be "name", or "labels."
            for map field. can be "<, >, <=, >=, !=, =, :". Of which ":"
            means HAS, and is roughly the same as "=". must be the same
            data type as field. can be "AND, OR, NOT".

            Examples of valid filters:

            -  "labels.owner" returns Namespaces that have a label with
               the key "owner" this is the same as "labels:owner".
            -  "labels.protocol=gRPC" returns Namespaces that have
               key/value "protocol=gRPC".
            -  "name>projects/my-project/locations/us-east/namespaces/namespace-c"
               returns Namespaces that have name that is alphabetically
               later than the string, so "namespace-e" will be returned
               but "namespace-a" will not be.
            -  "labels.owner!=sd AND labels.foo=bar" returns Namespaces
               that have "owner" in label key but value is not "sd" AND
               have key/value foo=bar.
            -  "doesnotexist.foo=bar" returns an empty list. Note that
               Namespace doesn't have a field called "doesnotexist".
               Since the filter does not match any Namespaces, it
               returns no results.
        order_by (str):
            Optional. The order to list result by.

            General order by string syntax: (<asc|desc>) (,) allows
            values {"name"} <asc/desc> ascending or descending order by
            . If this is left blank, "asc" is used. Note that an empty
            order_by string result in default order, which is order by
            name in ascending order.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )
    order_by: str = proto.Field(
        proto.STRING,
        number=5,
    )


class ListNamespacesResponse(proto.Message):
    r"""The response message for
    [RegistrationService.ListNamespaces][google.cloud.servicedirectory.v1.RegistrationService.ListNamespaces].

    Attributes:
        namespaces (MutableSequence[google.cloud.servicedirectory_v1.types.Namespace]):
            The list of namespaces.
        next_page_token (str):
            Token to retrieve the next page of results,
            or empty if there are no more results in the
            list.
    """

    @property
    def raw_page(self):
        return self

    namespaces: MutableSequence[gcs_namespace.Namespace] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=gcs_namespace.Namespace,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class GetNamespaceRequest(proto.Message):
    r"""The request message for
    [RegistrationService.GetNamespace][google.cloud.servicedirectory.v1.RegistrationService.GetNamespace].

    Attributes:
        name (str):
            Required. The name of the namespace to
            retrieve.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class UpdateNamespaceRequest(proto.Message):
    r"""The request message for
    [RegistrationService.UpdateNamespace][google.cloud.servicedirectory.v1.RegistrationService.UpdateNamespace].

    Attributes:
        namespace (google.cloud.servicedirectory_v1.types.Namespace):
            Required. The updated namespace.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. List of fields to be updated in
            this request.
    """

    namespace: gcs_namespace.Namespace = proto.Field(
        proto.MESSAGE,
        number=1,
        message=gcs_namespace.Namespace,
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class DeleteNamespaceRequest(proto.Message):
    r"""The request message for
    [RegistrationService.DeleteNamespace][google.cloud.servicedirectory.v1.RegistrationService.DeleteNamespace].

    Attributes:
        name (str):
            Required. The name of the namespace to
            delete.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class CreateServiceRequest(proto.Message):
    r"""The request message for
    [RegistrationService.CreateService][google.cloud.servicedirectory.v1.RegistrationService.CreateService].

    Attributes:
        parent (str):
            Required. The resource name of the namespace
            this service will belong to.
        service_id (str):
            Required. The Resource ID must be 1-63 characters long, and
            comply with RFC1035. Specifically, the name must be 1-63
            characters long and match the regular expression
            ``[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?`` which means the first
            character must be a lowercase letter, and all following
            characters must be a dash, lowercase letter, or digit,
            except the last character, which cannot be a dash.
        service (google.cloud.servicedirectory_v1.types.Service):
            Required. A service  with initial fields set.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    service_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    service: gcs_service.Service = proto.Field(
        proto.MESSAGE,
        number=3,
        message=gcs_service.Service,
    )


class ListServicesRequest(proto.Message):
    r"""The request message for
    [RegistrationService.ListServices][google.cloud.servicedirectory.v1.RegistrationService.ListServices].

    Attributes:
        parent (str):
            Required. The resource name of the namespace
            whose services we'd like to list.
        page_size (int):
            Optional. The maximum number of items to
            return.
        page_token (str):
            Optional. The next_page_token value returned from a previous
            List request, if any.
        filter (str):
            Optional. The filter to list result by.

            General filter string syntax: () can be "name", or
            "metadata." for map field. can be "<, >, <=, >=, !=, =, :".
            Of which ":" means HAS, and is roughly the same as "=". must
            be the same data type as field. can be "AND, OR, NOT".

            Examples of valid filters:

            -  "metadata.owner" returns Services that have a label with
               the key "owner" this is the same as "metadata:owner".
            -  "metadata.protocol=gRPC" returns Services that have
               key/value "protocol=gRPC".
            -  "name>projects/my-project/locations/us-east/namespaces/my-namespace/services/service-c"
               returns Services that have name that is alphabetically
               later than the string, so "service-e" will be returned
               but "service-a" will not be.
            -  "metadata.owner!=sd AND metadata.foo=bar" returns
               Services that have "owner" in label key but value is not
               "sd" AND have key/value foo=bar.
            -  "doesnotexist.foo=bar" returns an empty list. Note that
               Service doesn't have a field called "doesnotexist". Since
               the filter does not match any Services, it returns no
               results.
        order_by (str):
            Optional. The order to list result by.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )
    order_by: str = proto.Field(
        proto.STRING,
        number=5,
    )


class ListServicesResponse(proto.Message):
    r"""The response message for
    [RegistrationService.ListServices][google.cloud.servicedirectory.v1.RegistrationService.ListServices].

    Attributes:
        services (MutableSequence[google.cloud.servicedirectory_v1.types.Service]):
            The list of services.
        next_page_token (str):
            Token to retrieve the next page of results,
            or empty if there are no more results in the
            list.
    """

    @property
    def raw_page(self):
        return self

    services: MutableSequence[gcs_service.Service] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=gcs_service.Service,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class GetServiceRequest(proto.Message):
    r"""The request message for
    [RegistrationService.GetService][google.cloud.servicedirectory.v1.RegistrationService.GetService].
    This should not be used for looking up a service. Insead, use the
    ``resolve`` method as it will contain all endpoints and associated
    metadata.

    Attributes:
        name (str):
            Required. The name of the service to get.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class UpdateServiceRequest(proto.Message):
    r"""The request message for
    [RegistrationService.UpdateService][google.cloud.servicedirectory.v1.RegistrationService.UpdateService].

    Attributes:
        service (google.cloud.servicedirectory_v1.types.Service):
            Required. The updated service.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. List of fields to be updated in
            this request.
    """

    service: gcs_service.Service = proto.Field(
        proto.MESSAGE,
        number=1,
        message=gcs_service.Service,
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class DeleteServiceRequest(proto.Message):
    r"""The request message for
    [RegistrationService.DeleteService][google.cloud.servicedirectory.v1.RegistrationService.DeleteService].

    Attributes:
        name (str):
            Required. The name of the service to delete.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class CreateEndpointRequest(proto.Message):
    r"""The request message for
    [RegistrationService.CreateEndpoint][google.cloud.servicedirectory.v1.RegistrationService.CreateEndpoint].

    Attributes:
        parent (str):
            Required. The resource name of the service
            that this endpoint provides.
        endpoint_id (str):
            Required. The Resource ID must be 1-63 characters long, and
            comply with RFC1035. Specifically, the name must be 1-63
            characters long and match the regular expression
            ``[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?`` which means the first
            character must be a lowercase letter, and all following
            characters must be a dash, lowercase letter, or digit,
            except the last character, which cannot be a dash.
        endpoint (google.cloud.servicedirectory_v1.types.Endpoint):
            Required. A endpoint with initial fields set.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    endpoint_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    endpoint: gcs_endpoint.Endpoint = proto.Field(
        proto.MESSAGE,
        number=3,
        message=gcs_endpoint.Endpoint,
    )


class ListEndpointsRequest(proto.Message):
    r"""The request message for
    [RegistrationService.ListEndpoints][google.cloud.servicedirectory.v1.RegistrationService.ListEndpoints].

    Attributes:
        parent (str):
            Required. The resource name of the service
            whose endpoints we'd like to list.
        page_size (int):
            Optional. The maximum number of items to
            return.
        page_token (str):
            Optional. The next_page_token value returned from a previous
            List request, if any.
        filter (str):
            Optional. The filter to list result by.

            General filter string syntax: () can be "name", "address",
            "port" or "metadata." for map field. can be "<, >, <=, >=,
            !=, =, :". Of which ":" means HAS, and is roughly the same
            as "=". must be the same data type as field. can be "AND,
            OR, NOT".

            Examples of valid filters:

            -  "metadata.owner" returns Endpoints that have a label with
               the key "owner" this is the same as "metadata:owner".
            -  "metadata.protocol=gRPC" returns Endpoints that have
               key/value "protocol=gRPC".
            -  "address=192.108.1.105" returns Endpoints that have this
               address.
            -  "port>8080" returns Endpoints that have port number
               larger than 8080.
            -  "name>projects/my-project/locations/us-east/namespaces/my-namespace/services/my-service/endpoints/endpoint-c"
               returns Endpoints that have name that is alphabetically
               later than the string, so "endpoint-e" will be returned
               but "endpoint-a" will not be.
            -  "metadata.owner!=sd AND metadata.foo=bar" returns
               Endpoints that have "owner" in label key but value is not
               "sd" AND have key/value foo=bar.
            -  "doesnotexist.foo=bar" returns an empty list. Note that
               Endpoint doesn't have a field called "doesnotexist".
               Since the filter does not match any Endpoints, it returns
               no results.
        order_by (str):
            Optional. The order to list result by.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )
    order_by: str = proto.Field(
        proto.STRING,
        number=5,
    )


class ListEndpointsResponse(proto.Message):
    r"""The response message for
    [RegistrationService.ListEndpoints][google.cloud.servicedirectory.v1.RegistrationService.ListEndpoints].

    Attributes:
        endpoints (MutableSequence[google.cloud.servicedirectory_v1.types.Endpoint]):
            The list of endpoints.
        next_page_token (str):
            Token to retrieve the next page of results,
            or empty if there are no more results in the
            list.
    """

    @property
    def raw_page(self):
        return self

    endpoints: MutableSequence[gcs_endpoint.Endpoint] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=gcs_endpoint.Endpoint,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class GetEndpointRequest(proto.Message):
    r"""The request message for
    [RegistrationService.GetEndpoint][google.cloud.servicedirectory.v1.RegistrationService.GetEndpoint].
    This should not be used to lookup endpoints at runtime. Instead, use
    the ``resolve`` method.

    Attributes:
        name (str):
            Required. The name of the endpoint to get.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class UpdateEndpointRequest(proto.Message):
    r"""The request message for
    [RegistrationService.UpdateEndpoint][google.cloud.servicedirectory.v1.RegistrationService.UpdateEndpoint].

    Attributes:
        endpoint (google.cloud.servicedirectory_v1.types.Endpoint):
            Required. The updated endpoint.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. List of fields to be updated in
            this request.
    """

    endpoint: gcs_endpoint.Endpoint = proto.Field(
        proto.MESSAGE,
        number=1,
        message=gcs_endpoint.Endpoint,
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class DeleteEndpointRequest(proto.Message):
    r"""The request message for
    [RegistrationService.DeleteEndpoint][google.cloud.servicedirectory.v1.RegistrationService.DeleteEndpoint].

    Attributes:
        name (str):
            Required. The name of the endpoint to delete.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.servicedirectory.v1beta1",
    manifest={
        "Namespace",
    },
)


class Namespace(proto.Message):
    r"""A container for
    [services][google.cloud.servicedirectory.v1beta1.Service].
    Namespaces allow administrators to group services together and
    define permissions for a collection of services.

    Attributes:
        name (str):
            Immutable. The resource name for the namespace in the format
            ``projects/*/locations/*/namespaces/*``.
        labels (MutableMapping[str, str]):
            Optional. Resource labels associated with
            this namespace. No more than 64 user labels can
            be associated with a given resource. Label keys
            and values can be no longer than 63 characters.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The timestamp when the namespace
            was created.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The timestamp when the namespace
            was last updated.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=2,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=4,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=5,
        message=timestamp_pb2.Timestamp,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.cloud.servicedirectory_v1.types import service as gcs_service

__protobuf__ = proto.module(
    package="google.cloud.servicedirectory.v1",
    manifest={
        "ResolveServiceRequest",
        "ResolveServiceResponse",
    },
)


class ResolveServiceRequest(proto.Message):
    r"""The request message for
    [LookupService.ResolveService][google.cloud.servicedirectory.v1.LookupService.ResolveService].
    Looks up a service by its name, returns the service and its
    endpoints.

    Attributes:
        name (str):
            Required. The name of the service to resolve.
        max_endpoints (int):
            Optional. The maximum number of endpoints to
            return. Defaults to 25. Maximum is 100. If a
            value less than one is specified, the Default is
            used. If a value greater than the Maximum is
            specified, the Maximum is used.
        endpoint_filter (str):
            Optional. The filter applied to the endpoints of the
            resolved service.

            General filter string syntax: () can be "name" or
            "metadata." for map field. can be "<, >, <=, >=, !=, =, :".
            Of which ":" means HAS and is roughly the same as "=". must
            be the same data type as the field. can be "AND, OR, NOT".

            Examples of valid filters:

            -  "metadata.owner" returns Endpoints that have a label with
               the key "owner", this is the same as "metadata:owner"
            -  "metadata.protocol=gRPC" returns Endpoints that have
               key/value "protocol=gRPC"
            -  "metadata.owner!=sd AND metadata.foo=bar" returns
               Endpoints that have "owner" field in metadata with a
               value that is not "sd" AND have the key/value foo=bar.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    max_endpoints: int = proto.Field(
        proto.INT32,
        number=2,
    )
    endpoint_filter: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ResolveServiceResponse(proto.Message):
    r"""The response message for
    [LookupService.ResolveService][google.cloud.servicedirectory.v1.LookupService.ResolveService].

    Attributes:
        service (google.cloud.servicedirectory_v1.types.Service):

    """

    service: gcs_service.Service = proto.Field(
        proto.MESSAGE,
        number=1,
        message=gcs_service.Service,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from collections import OrderedDict
import functools
import re
from typing import (
    Dict,
    Mapping,
    MutableMapping,
    MutableSequence,
    Optional,
    Sequence,
    Tuple,
    Type,
    Union,
)

from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
from google.api_core.client_options import ClientOptions
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.cloud.servicedirectory_v1beta1 import gapic_version as package_version

try:
    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
except AttributeError:  # pragma: NO COVER
    OptionalRetry = Union[retries.Retry, object]  # type: ignore

from google.cloud.servicedirectory_v1beta1.types import lookup_service, service

from .client import LookupServiceClient
from .transports.base import DEFAULT_CLIENT_INFO, LookupServiceTransport
from .transports.grpc_asyncio import LookupServiceGrpcAsyncIOTransport


class LookupServiceAsyncClient:
    """Service Directory API for looking up service data at runtime."""

    _client: LookupServiceClient

    DEFAULT_ENDPOINT = LookupServiceClient.DEFAULT_ENDPOINT
    DEFAULT_MTLS_ENDPOINT = LookupServiceClient.DEFAULT_MTLS_ENDPOINT

    endpoint_path = staticmethod(LookupServiceClient.endpoint_path)
    parse_endpoint_path = staticmethod(LookupServiceClient.parse_endpoint_path)
    network_path = staticmethod(LookupServiceClient.network_path)
    parse_network_path = staticmethod(LookupServiceClient.parse_network_path)
    service_path = staticmethod(LookupServiceClient.service_path)
    parse_service_path = staticmethod(LookupServiceClient.parse_service_path)
    common_billing_account_path = staticmethod(
        LookupServiceClient.common_billing_account_path
    )
    parse_common_billing_account_path = staticmethod(
        LookupServiceClient.parse_common_billing_account_path
    )
    common_folder_path = staticmethod(LookupServiceClient.common_folder_path)
    parse_common_folder_path = staticmethod(
        LookupServiceClient.parse_common_folder_path
    )
    common_organization_path = staticmethod(
        LookupServiceClient.common_organization_path
    )
    parse_common_organization_path = staticmethod(
        LookupServiceClient.parse_common_organization_path
    )
    common_project_path = staticmethod(LookupServiceClient.common_project_path)
    parse_common_project_path = staticmethod(
        LookupServiceClient.parse_common_project_path
    )
    common_location_path = staticmethod(LookupServiceClient.common_location_path)
    parse_common_location_path = staticmethod(
        LookupServiceClient.parse_common_location_path
    )

    @classmethod
    def from_service_account_info(cls, info: dict, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
            info.

        Args:
            info (dict): The service account private key info.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            LookupServiceAsyncClient: The constructed client.
        """
        return LookupServiceClient.from_service_account_info.__func__(LookupServiceAsyncClient, info, *args, **kwargs)  # type: ignore

    @classmethod
    def from_service_account_file(cls, filename: str, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
            file.

        Args:
            filename (str): The path to the service account private key json
                file.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            LookupServiceAsyncClient: The constructed client.
        """
        return LookupServiceClient.from_service_account_file.__func__(LookupServiceAsyncClient, filename, *args, **kwargs)  # type: ignore

    from_service_account_json = from_service_account_file

    @classmethod
    def get_mtls_endpoint_and_cert_source(
        cls, client_options: Optional[ClientOptions] = None
    ):
        """Return the API endpoint and client cert source for mutual TLS.

        The client cert source is determined in the following order:
        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
        client cert source is None.
        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
        default client cert source exists, use the default one; otherwise the client cert
        source is None.

        The API endpoint is determined in the following order:
        (1) if `client_options.api_endpoint` if provided, use the provided one.
        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
        default mTLS endpoint; if the environment variable is "never", use the default API
        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
        use the default API endpoint.

        More details can be found at https://google.aip.dev/auth/4114.

        Args:
            client_options (google.api_core.client_options.ClientOptions): Custom options for the
                client. Only the `api_endpoint` and `client_cert_source` properties may be used
                in this method.

        Returns:
            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
                client cert source to use.

        Raises:
            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
        """
        return LookupServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore

    @property
    def transport(self) -> LookupServiceTransport:
        """Returns the transport used by the client instance.

        Returns:
            LookupServiceTransport: The transport used by the client instance.
        """
        return self._client.transport

    get_transport_class = functools.partial(
        type(LookupServiceClient).get_transport_class, type(LookupServiceClient)
    )

    def __init__(
        self,
        *,
        credentials: Optional[ga_credentials.Credentials] = None,
        transport: Union[str, LookupServiceTransport] = "grpc_asyncio",
        client_options: Optional[ClientOptions] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
    ) -> None:
        """Instantiates the lookup service client.

        Args:
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            transport (Union[str, ~.LookupServiceTransport]): The
                transport to use. If set to None, a transport is chosen
                automatically.
            client_options (ClientOptions): Custom options for the client. It
                won't take effect if a ``transport`` instance is provided.
                (1) The ``api_endpoint`` property can be used to override the
                default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
                environment variable can also be used to override the endpoint:
                "always" (always use the default mTLS endpoint), "never" (always
                use the default regular endpoint) and "auto" (auto switch to the
                default mTLS endpoint if client certificate is present, this is
                the default value). However, the ``api_endpoint`` property takes
                precedence if provided.
                (2) If GOOGLE_API_USE_CLIENT_CERTIFICATE environment variable
                is "true", then the ``client_cert_source`` property can be used
                to provide client certificate for mutual TLS transport. If
                not provided, the default SSL client certificate will be used if
                present. If GOOGLE_API_USE_CLIENT_CERTIFICATE is "false" or not
                set, no client certificate will be used.

        Raises:
            google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                creation failed for any reason.
        """
        self._client = LookupServiceClient(
            credentials=credentials,
            transport=transport,
            client_options=client_options,
            client_info=client_info,
        )

    async def resolve_service(
        self,
        request: Optional[Union[lookup_service.ResolveServiceRequest, dict]] = None,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> lookup_service.ResolveServiceResponse:
        r"""Returns a
        [service][google.cloud.servicedirectory.v1beta1.Service] and its
        associated endpoints. Resolving a service is not considered an
        active developer method.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import servicedirectory_v1beta1

            async def sample_resolve_service():
                # Create a client
                client = servicedirectory_v1beta1.LookupServiceAsyncClient()

                # Initialize request argument(s)
                request = servicedirectory_v1beta1.ResolveServiceRequest(
                    name="name_value",
                )

                # Make the request
                response = await client.resolve_service(request=request)

                # Handle the response
                print(response)

        Args:
            request (Optional[Union[google.cloud.servicedirectory_v1beta1.types.ResolveServiceRequest, dict]]):
                The request object. The request message for
                [LookupService.ResolveService][google.cloud.servicedirectory.v1beta1.LookupService.ResolveService].
                Looks up a service by its name, returns the service and
                its endpoints.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.servicedirectory_v1beta1.types.ResolveServiceResponse:
                The response message for
                [LookupService.ResolveService][google.cloud.servicedirectory.v1beta1.LookupService.ResolveService].

        """
        # Create or coerce a protobuf request object.
        request = lookup_service.ResolveServiceRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.resolve_service,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def __aenter__(self):
        return self

    async def __aexit__(self, exc_type, exc, tb):
        await self.transport.close()


DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
    gapic_version=package_version.__version__
)


__all__ = ("LookupServiceAsyncClient",)



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.servicedirectory_v1beta1.types import endpoint as gcs_endpoint
from google.cloud.servicedirectory_v1beta1.types import namespace as gcs_namespace
from google.cloud.servicedirectory_v1beta1.types import service as gcs_service

__protobuf__ = proto.module(
    package="google.cloud.servicedirectory.v1beta1",
    manifest={
        "CreateNamespaceRequest",
        "ListNamespacesRequest",
        "ListNamespacesResponse",
        "GetNamespaceRequest",
        "UpdateNamespaceRequest",
        "DeleteNamespaceRequest",
        "CreateServiceRequest",
        "ListServicesRequest",
        "ListServicesResponse",
        "GetServiceRequest",
        "UpdateServiceRequest",
        "DeleteServiceRequest",
        "CreateEndpointRequest",
        "ListEndpointsRequest",
        "ListEndpointsResponse",
        "GetEndpointRequest",
        "UpdateEndpointRequest",
        "DeleteEndpointRequest",
    },
)


class CreateNamespaceRequest(proto.Message):
    r"""The request message for
    [RegistrationService.CreateNamespace][google.cloud.servicedirectory.v1beta1.RegistrationService.CreateNamespace].

    Attributes:
        parent (str):
            Required. The resource name of the project
            and location the namespace will be created in.
        namespace_id (str):
            Required. The Resource ID must be 1-63 characters long, and
            comply with RFC1035. Specifically, the name must be 1-63
            characters long and match the regular expression
            ``[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?`` which means the first
            character must be a lowercase letter, and all following
            characters must be a dash, lowercase letter, or digit,
            except the last character, which cannot be a dash.
        namespace (google.cloud.servicedirectory_v1beta1.types.Namespace):
            Required. A namespace with initial fields
            set.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    namespace_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    namespace: gcs_namespace.Namespace = proto.Field(
        proto.MESSAGE,
        number=3,
        message=gcs_namespace.Namespace,
    )


class ListNamespacesRequest(proto.Message):
    r"""The request message for
    [RegistrationService.ListNamespaces][google.cloud.servicedirectory.v1beta1.RegistrationService.ListNamespaces].

    Attributes:
        parent (str):
            Required. The resource name of the project
            and location whose namespaces you'd like to
            list.
        page_size (int):
            Optional. The maximum number of items to
            return.
        page_token (str):
            Optional. The next_page_token value returned from a previous
            List request, if any.
        filter (str):
            Optional. The filter to list results by.

            General ``filter`` string syntax:
            ``<field> <operator> <value> (<logical connector>)``

            -  ``<field>`` can be ``name`` or ``labels.<key>`` for map
               field
            -  ``<operator>`` can be ``<``, ``>``, ``<=``, ``>=``,
               ``!=``, ``=``, ``:``. Of which ``:`` means ``HAS``, and
               is roughly the same as ``=``
            -  ``<value>`` must be the same data type as field
            -  ``<logical connector>`` can be ``AND``, ``OR``, ``NOT``

            Examples of valid filters:

            -  ``labels.owner`` returns namespaces that have a label
               with the key ``owner``, this is the same as
               ``labels:owner``
            -  ``labels.owner=sd`` returns namespaces that have
               key/value ``owner=sd``
            -  ``name>projects/my-project/locations/us-east1/namespaces/namespace-c``
               returns namespaces that have name that is alphabetically
               later than the string, so "namespace-e" is returned but
               "namespace-a" is not
            -  ``labels.owner!=sd AND labels.foo=bar`` returns
               namespaces that have ``owner`` in label key but value is
               not ``sd`` AND have key/value ``foo=bar``
            -  ``doesnotexist.foo=bar`` returns an empty list. Note that
               namespace doesn't have a field called "doesnotexist".
               Since the filter does not match any namespaces, it
               returns no results

            For more information about filtering, see `API
            Filtering <https://aip.dev/160>`__.
        order_by (str):
            Optional. The order to list results by.

            General ``order_by`` string syntax:
            ``<field> (<asc|desc>) (,)``

            -  ``<field>`` allows value: ``name``
            -  ``<asc|desc>`` ascending or descending order by
               ``<field>``. If this is left blank, ``asc`` is used

            Note that an empty ``order_by`` string results in default
            order, which is order by ``name`` in ascending order.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )
    order_by: str = proto.Field(
        proto.STRING,
        number=5,
    )


class ListNamespacesResponse(proto.Message):
    r"""The response message for
    [RegistrationService.ListNamespaces][google.cloud.servicedirectory.v1beta1.RegistrationService.ListNamespaces].

    Attributes:
        namespaces (MutableSequence[google.cloud.servicedirectory_v1beta1.types.Namespace]):
            The list of namespaces.
        next_page_token (str):
            Token to retrieve the next page of results,
            or empty if there are no more results in the
            list.
    """

    @property
    def raw_page(self):
        return self

    namespaces: MutableSequence[gcs_namespace.Namespace] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=gcs_namespace.Namespace,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class GetNamespaceRequest(proto.Message):
    r"""The request message for
    [RegistrationService.GetNamespace][google.cloud.servicedirectory.v1beta1.RegistrationService.GetNamespace].

    Attributes:
        name (str):
            Required. The name of the namespace to
            retrieve.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class UpdateNamespaceRequest(proto.Message):
    r"""The request message for
    [RegistrationService.UpdateNamespace][google.cloud.servicedirectory.v1beta1.RegistrationService.UpdateNamespace].

    Attributes:
        namespace (google.cloud.servicedirectory_v1beta1.types.Namespace):
            Required. The updated namespace.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. List of fields to be updated in
            this request.
    """

    namespace: gcs_namespace.Namespace = proto.Field(
        proto.MESSAGE,
        number=1,
        message=gcs_namespace.Namespace,
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class DeleteNamespaceRequest(proto.Message):
    r"""The request message for
    [RegistrationService.DeleteNamespace][google.cloud.servicedirectory.v1beta1.RegistrationService.DeleteNamespace].

    Attributes:
        name (str):
            Required. The name of the namespace to
            delete.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class CreateServiceRequest(proto.Message):
    r"""The request message for
    [RegistrationService.CreateService][google.cloud.servicedirectory.v1beta1.RegistrationService.CreateService].

    Attributes:
        parent (str):
            Required. The resource name of the namespace
            this service will belong to.
        service_id (str):
            Required. The Resource ID must be 1-63 characters long, and
            comply with RFC1035. Specifically, the name must be 1-63
            characters long and match the regular expression
            ``[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?`` which means the first
            character must be a lowercase letter, and all following
            characters must be a dash, lowercase letter, or digit,
            except the last character, which cannot be a dash.
        service (google.cloud.servicedirectory_v1beta1.types.Service):
            Required. A service  with initial fields set.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    service_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    service: gcs_service.Service = proto.Field(
        proto.MESSAGE,
        number=3,
        message=gcs_service.Service,
    )


class ListServicesRequest(proto.Message):
    r"""The request message for
    [RegistrationService.ListServices][google.cloud.servicedirectory.v1beta1.RegistrationService.ListServices].

    Attributes:
        parent (str):
            Required. The resource name of the namespace
            whose services you'd like to list.
        page_size (int):
            Optional. The maximum number of items to
            return.
        page_token (str):
            Optional. The next_page_token value returned from a previous
            List request, if any.
        filter (str):
            Optional. The filter to list results by.

            General ``filter`` string syntax:
            ``<field> <operator> <value> (<logical connector>)``

            -  ``<field>`` can be ``name`` or ``metadata.<key>`` for map
               field
            -  ``<operator>`` can be ``<``, ``>``, ``<=``, ``>=``,
               ``!=``, ``=``, ``:``. Of which ``:`` means ``HAS``, and
               is roughly the same as ``=``
            -  ``<value>`` must be the same data type as field
            -  ``<logical connector>`` can be ``AND``, ``OR``, ``NOT``

            Examples of valid filters:

            -  ``metadata.owner`` returns services that have a metadata
               with the key ``owner``, this is the same as
               ``metadata:owner``
            -  ``metadata.protocol=gRPC`` returns services that have
               key/value ``protocol=gRPC``
            -

            ``name>projects/my-project/locations/us-east1/namespaces/my-namespace/services/service-c``
            returns services that have name that is alphabetically later
            than the string, so "service-e" is returned but "service-a"
            is not

            -  ``metadata.owner!=sd AND metadata.foo=bar`` returns
               services that have ``owner`` in metadata key but value is
               not ``sd`` AND have key/value ``foo=bar``
            -  ``doesnotexist.foo=bar`` returns an empty list. Note that
               service doesn't have a field called "doesnotexist". Since
               the filter does not match any services, it returns no
               results

            For more information about filtering, see `API
            Filtering <https://aip.dev/160>`__.
        order_by (str):
            Optional. The order to list results by.

            General ``order_by`` string syntax:
            ``<field> (<asc|desc>) (,)``

            -  ``<field>`` allows value: ``name``
            -  ``<asc|desc>`` ascending or descending order by
               ``<field>``. If this is left blank, ``asc`` is used

            Note that an empty ``order_by`` string results in default
            order, which is order by ``name`` in ascending order.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )
    order_by: str = proto.Field(
        proto.STRING,
        number=5,
    )


class ListServicesResponse(proto.Message):
    r"""The response message for
    [RegistrationService.ListServices][google.cloud.servicedirectory.v1beta1.RegistrationService.ListServices].

    Attributes:
        services (MutableSequence[google.cloud.servicedirectory_v1beta1.types.Service]):
            The list of services.
        next_page_token (str):
            Token to retrieve the next page of results,
            or empty if there are no more results in the
            list.
    """

    @property
    def raw_page(self):
        return self

    services: MutableSequence[gcs_service.Service] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=gcs_service.Service,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class GetServiceRequest(proto.Message):
    r"""The request message for
    [RegistrationService.GetService][google.cloud.servicedirectory.v1beta1.RegistrationService.GetService].
    This should not be used for looking up a service. Insead, use the
    ``resolve`` method as it contains all endpoints and associated
    metadata.

    Attributes:
        name (str):
            Required. The name of the service to get.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class UpdateServiceRequest(proto.Message):
    r"""The request message for
    [RegistrationService.UpdateService][google.cloud.servicedirectory.v1beta1.RegistrationService.UpdateService].

    Attributes:
        service (google.cloud.servicedirectory_v1beta1.types.Service):
            Required. The updated service.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. List of fields to be updated in
            this request.
    """

    service: gcs_service.Service = proto.Field(
        proto.MESSAGE,
        number=1,
        message=gcs_service.Service,
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class DeleteServiceRequest(proto.Message):
    r"""The request message for
    [RegistrationService.DeleteService][google.cloud.servicedirectory.v1beta1.RegistrationService.DeleteService].

    Attributes:
        name (str):
            Required. The name of the service to delete.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class CreateEndpointRequest(proto.Message):
    r"""The request message for
    [RegistrationService.CreateEndpoint][google.cloud.servicedirectory.v1beta1.RegistrationService.CreateEndpoint].

    Attributes:
        parent (str):
            Required. The resource name of the service
            that this endpoint provides.
        endpoint_id (str):
            Required. The Resource ID must be 1-63 characters long, and
            comply with RFC1035. Specifically, the name must be 1-63
            characters long and match the regular expression
            ``[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?`` which means the first
            character must be a lowercase letter, and all following
            characters must be a dash, lowercase letter, or digit,
            except the last character, which cannot be a dash.
        endpoint (google.cloud.servicedirectory_v1beta1.types.Endpoint):
            Required. A endpoint with initial fields set.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    endpoint_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    endpoint: gcs_endpoint.Endpoint = proto.Field(
        proto.MESSAGE,
        number=3,
        message=gcs_endpoint.Endpoint,
    )


class ListEndpointsRequest(proto.Message):
    r"""The request message for
    [RegistrationService.ListEndpoints][google.cloud.servicedirectory.v1beta1.RegistrationService.ListEndpoints].

    Attributes:
        parent (str):
            Required. The resource name of the service
            whose endpoints you'd like to list.
        page_size (int):
            Optional. The maximum number of items to
            return.
        page_token (str):
            Optional. The next_page_token value returned from a previous
            List request, if any.
        filter (str):
            Optional. The filter to list results by.

            General ``filter`` string syntax:
            ``<field> <operator> <value> (<logical connector>)``

            -  ``<field>`` can be ``name``, ``address``, ``port``, or
               ``metadata.<key>`` for map field
            -  ``<operator>`` can be ``<``, ``>``, ``<=``, ``>=``,
               ``!=``, ``=``, ``:``. Of which ``:`` means ``HAS``, and
               is roughly the same as ``=``
            -  ``<value>`` must be the same data type as field
            -  ``<logical connector>`` can be ``AND``, ``OR``, ``NOT``

            Examples of valid filters:

            -  ``metadata.owner`` returns endpoints that have a metadata
               with the key ``owner``, this is the same as
               ``metadata:owner``
            -  ``metadata.protocol=gRPC`` returns endpoints that have
               key/value ``protocol=gRPC``
            -  ``address=192.108.1.105`` returns endpoints that have
               this address
            -  ``port>8080`` returns endpoints that have port number
               larger than 8080
            -

            ``name>projects/my-project/locations/us-east1/namespaces/my-namespace/services/my-service/endpoints/endpoint-c``
            returns endpoints that have name that is alphabetically
            later than the string, so "endpoint-e" is returned but
            "endpoint-a" is not

            -  ``metadata.owner!=sd AND metadata.foo=bar`` returns
               endpoints that have ``owner`` in metadata key but value
               is not ``sd`` AND have key/value ``foo=bar``
            -  ``doesnotexist.foo=bar`` returns an empty list. Note that
               endpoint doesn't have a field called "doesnotexist".
               Since the filter does not match any endpoints, it returns
               no results

            For more information about filtering, see `API
            Filtering <https://aip.dev/160>`__.
        order_by (str):
            Optional. The order to list results by.

            General ``order_by`` string syntax:
            ``<field> (<asc|desc>) (,)``

            -  ``<field>`` allows values: ``name``, ``address``,
               ``port``
            -  ``<asc|desc>`` ascending or descending order by
               ``<field>``. If this is left blank, ``asc`` is used

            Note that an empty ``order_by`` string results in default
            order, which is order by ``name`` in ascending order.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )
    order_by: str = proto.Field(
        proto.STRING,
        number=5,
    )


class ListEndpointsResponse(proto.Message):
    r"""The response message for
    [RegistrationService.ListEndpoints][google.cloud.servicedirectory.v1beta1.RegistrationService.ListEndpoints].

    Attributes:
        endpoints (MutableSequence[google.cloud.servicedirectory_v1beta1.types.Endpoint]):
            The list of endpoints.
        next_page_token (str):
            Token to retrieve the next page of results,
            or empty if there are no more results in the
            list.
    """

    @property
    def raw_page(self):
        return self

    endpoints: MutableSequence[gcs_endpoint.Endpoint] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=gcs_endpoint.Endpoint,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class GetEndpointRequest(proto.Message):
    r"""The request message for
    [RegistrationService.GetEndpoint][google.cloud.servicedirectory.v1beta1.RegistrationService.GetEndpoint].
    This should not be used to lookup endpoints at runtime. Instead, use
    the ``resolve`` method.

    Attributes:
        name (str):
            Required. The name of the endpoint to get.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class UpdateEndpointRequest(proto.Message):
    r"""The request message for
    [RegistrationService.UpdateEndpoint][google.cloud.servicedirectory.v1beta1.RegistrationService.UpdateEndpoint].

    Attributes:
        endpoint (google.cloud.servicedirectory_v1beta1.types.Endpoint):
            Required. The updated endpoint.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. List of fields to be updated in
            this request.
    """

    endpoint: gcs_endpoint.Endpoint = proto.Field(
        proto.MESSAGE,
        number=1,
        message=gcs_endpoint.Endpoint,
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class DeleteEndpointRequest(proto.Message):
    r"""The request message for
    [RegistrationService.DeleteEndpoint][google.cloud.servicedirectory.v1beta1.RegistrationService.DeleteEndpoint].

    Attributes:
        name (str):
            Required. The name of the endpoint to delete.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.servicedirectory_v1beta1.types import endpoint

__protobuf__ = proto.module(
    package="google.cloud.servicedirectory.v1beta1",
    manifest={
        "Service",
    },
)


class Service(proto.Message):
    r"""An individual service. A service contains a name and optional
    metadata. A service must exist before
    [endpoints][google.cloud.servicedirectory.v1beta1.Endpoint] can be
    added to it.

    Attributes:
        name (str):
            Immutable. The resource name for the service in the format
            ``projects/*/locations/*/namespaces/*/services/*``.
        metadata (MutableMapping[str, str]):
            Optional. Metadata for the service. This data can be
            consumed by service clients.

            Restrictions:

            -  The entire metadata dictionary may contain up to 2000
               characters, spread accoss all key-value pairs. Metadata
               that goes beyond this limit are rejected
            -  Valid metadata keys have two segments: an optional prefix
               and name, separated by a slash (/). The name segment is
               required and must be 63 characters or less, beginning and
               ending with an alphanumeric character ([a-z0-9A-Z]) with
               dashes (-), underscores (_), dots (.), and alphanumerics
               between. The prefix is optional. If specified, the prefix
               must be a DNS subdomain: a series of DNS labels separated
               by dots (.), not longer than 253 characters in total,
               followed by a slash (/). Metadata that fails to meet
               these requirements are rejected
            -  The ``(*.)google.com/`` and ``(*.)googleapis.com/``
               prefixes are reserved for system metadata managed by
               Service Directory. If the user tries to write to these
               keyspaces, those entries are silently ignored by the
               system

            Note: This field is equivalent to the ``annotations`` field
            in the v1 API. They have the same syntax and read/write to
            the same location in Service Directory.
        endpoints (MutableSequence[google.cloud.servicedirectory_v1beta1.types.Endpoint]):
            Output only. Endpoints associated with this service.
            Returned on
            [LookupService.ResolveService][google.cloud.servicedirectory.v1beta1.LookupService.ResolveService].
            Control plane clients should use
            [RegistrationService.ListEndpoints][google.cloud.servicedirectory.v1beta1.RegistrationService.ListEndpoints].
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The timestamp when the service
            was created.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The timestamp when the service
            was last updated. Note: endpoints being
            created/deleted/updated within the service are
            not considered service updates for the purpose
            of this timestamp.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    metadata: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=2,
    )
    endpoints: MutableSequence[endpoint.Endpoint] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message=endpoint.Endpoint,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=6,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=7,
        message=timestamp_pb2.Timestamp,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
